@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: courieroblique.pm,v 1.5 2004/06/15 09:14:53 fredo Exp $
+#   $Id: courieroblique.pm,v 1.7 2005/06/07 23:21:39 fredo Exp $
 #
 #=======================================================================
 
 $fonts->{courieroblique}= {
     'fontname' => 'Courier-Oblique',
     'type' => 'Type1',
-    'apiname' => 'Co4',
+    'apiname' => 'CoIt',
     'ascender' => '629',
     'capheight' => '562',
     'descender' => '-157',
@@ -551,6 +551,12 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: courieroblique.pm,v $
+    Revision 1.7  2005/06/07 23:21:39  fredo
+    fontkey correction
+
+    Revision 1.6  2005/03/14 22:01:28  fredo
+    upd 2005
+
     Revision 1.5  2004/06/15 09:14:53  fredo
     removed cr+lf
 
