@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: helvetica.pm,v 1.4 2004/06/07 19:44:43 fredo Exp $
+#   $Id: helvetica.pm,v 1.7 2005/06/07 23:21:39 fredo Exp $
 #
 #=======================================================================
 
 $fonts->{helvetica}= {
     'fontname' => 'Helvetica',
     'type' => 'Type1',
-    'apiname' => 'He1',
+    'apiname' => 'Helv',
     'ascender' => '718',
     'capheight' => '718',
     'descender' => '-207',
@@ -551,6 +551,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: helvetica.pm,v $
+    Revision 1.7  2005/06/07 23:21:39  fredo
+    fontkey correction
+
+    Revision 1.6  2005/03/14 22:01:29  fredo
+    upd 2005
+
+    Revision 1.5  2004/06/15 09:14:53  fredo
+    removed cr+lf
+
     Revision 1.4  2004/06/07 19:44:43  fredo
     cleaned out cr+lf for lf
 
