@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,14 +27,14 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: trebuchetitalic.pm,v 1.4 2004/06/07 19:44:44 fredo Exp $
+#   $Id: trebuchetitalic.pm,v 1.7 2005/06/07 23:21:40 fredo Exp $
 #
 #=======================================================================
 
 $fonts->{trebuchetitalic}= {
     'fontname' => 'TrebuchetMS,Italic',
     'type' => 'TrueType',
-    'apiname' => 'Tr4',
+    'apiname' => 'TrIt',
     'ascender' => '938',
     'capheight' => '715',
     'descender' => '-222',
@@ -666,6 +666,15 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: trebuchetitalic.pm,v $
+    Revision 1.7  2005/06/07 23:21:40  fredo
+    fontkey correction
+
+    Revision 1.6  2005/03/14 22:01:30  fredo
+    upd 2005
+
+    Revision 1.5  2004/06/15 09:14:53  fredo
+    removed cr+lf
+
     Revision 1.4  2004/06/07 19:44:44  fredo
     cleaned out cr+lf for lf
 
